/*! \file can_config.c \brief CAN driver with limited can support. */
// *****************************************************************************
//
// File Name	: 'can_config.c'
// Title		: CAN driver with limited can support
// Author		: Markus Schiesser 2007
// Created		: 01/01/2007
// Revised		: 04/27/2007
// Version		: 0.7
// Target MCU	: ATMEL AVR Series
// Editor Tabs	: 3
//
// Supports:	extended frame ID (CAN 2.0B)
//				interrupt driven RX/TX
//				polling RX/TX
//				up to 15 message objects
// Not supported:
//				standart frame ID (CAN2.0A)
//				remote frames
//				Frame buffer mode
//				and few other things		
//
// *****************************************************************************

#ifndef _CAN_CONFIG_H_
#define _CAN_CONFIG_H_


//------ I N C L U D E S -----

#include "config.h"

//----- D E F I N I T I O N S ----- 

// max numbers of mob
#define MAX_MOB 	15		
#define CAN_BAUDRATE			100 		//define CAN bus speed 100,125,200,250,500,1000

//----- INTERUPT DEFINITIONS -----
#define CAN_INTERRUPT			ENABLE		//General CAN Interrupt ENABLE / DISABLE

#define CAN_BOFF_INTERRUPT		DISABLE		//Bus Off interrrupt ENABLE / DISABLE
#define CAN_RXOK_INTERRUPT		ENABLE		//RX_OK Interrupt ENABLE / DISABLE
#define CAN_TXOK_INTERRUPT		ENABLE		//TX_OK Interrupt ENABLE / DISABLE
#define CAN_ERROR_MOB_INTERRUPT	ENABLE		//MOB ERROR Interrupt ENABLE / DISABLE
#define CAN_FRAMEBUF_INTERRUPT	DISABLE		//Frambuffer Interrupt ENABLE / DISABLE
#define CAN_GEN_ERROR_INTERRUPT ENABLE		//General Error Interrupt ENABLE / DISABLE
#define CAN_TIMER_INTERRUPT		DISABLE		//Timer Overrun Interrupt ENABLE / DISABLE


//----- D E C L A R A T I O N S -----

// Struct error and transmission counter

struct CAN_Error_struct{
	uint8_t  DLCW_count;	//Data Length Code Warning
	uint8_t  BERR_count;	//Bit Error
	uint8_t  SERR_count;	//Stuff Error
	uint8_t  CRC_count;		//CRC Error
	uint8_t  FERR_count;	//Form Error
	uint8_t  AERR_count;	//Acknowledgment Error
	uint8_t  TXOK_count;	//TX_OK
	uint8_t  RXOK_count;	//RX_OK
	uint8_t  RX_Frame_lost; //RX_Frame_lost
	uint8_t  TX_Frame_lost; //RX_Frame_lost
	uint16_t Byte_TX;		//Bytes Transmitted
	uint16_t Byte_RX;		//Bytes Received
} CAN_Counter;


//MOb transmission struct
struct MOb_struct{
	uint32_t ext_id;
	uint8_t  MOb_number;
	uint8_t  data_length;
	uint8_t	 msg[8];
	unsigned valid:1;
 } MOb_TX, MOb_RX;


#endif  /* CAN_CONFIG_H */
